use crate::CoinValue;

/// Maximum coin value
pub const MAX_COINVAL: CoinValue = CoinValue(1 << 120);

/// 1e6
pub const MICRO_CONVERTER: u128 = 1_000_000;

/// A stake epoch is 200,000 blocks.
pub const STAKE_EPOCH: u64 = 200000;
